(************** Content-type: application/mathematica **************
                     CreatedBy='Mathematica 5.1'

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[     14768,        384]*)
(*NotebookOutlinePosition[     15488,        408]*)
(*  CellTagsIndexPosition[     15444,        404]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Hertzsprung-Russell Diagram", "Chapter"],

Cell["\<\
  The Hertzsprung-Russell diagram, or H-R diagram, was pioneered \
independently by Elnar Hertzsprung and Henry Norris Russell and typically \
plots luminosity versus temperature for stars. It is a graphical tool that \
astronomers use to classify stars according to their luminosity, spectral \
type, color, temperature and evolutionary stage.  \
\>", "Text"],

Cell[CellGroupData[{

Cell["Background", "Subsection"],

Cell["\<\
  Stars on the left side of the diagram are hotter, while those on the right \
or cooler. This translates into color differences.  Blue stars are on the \
left and red stars are on the right as would be expected for a classic \
blackbody.  Stars are very nearly blackbodies and so we can use Plank's \
Blackbody Radiation Law to calculate the intensity of radiation for a given \
wavelength and stellar surface temperature.\
\>", "Text"],

Cell[CellGroupData[{

Cell["Plank's Blackbody Radiation Law", "Subsubsection"],

Cell["\<\
  Stars are very nearly blackbodies and so we can use Plank's Blackbody \
Radiation Law to calculate the intensity of radiation for a given wavelength \
and stellar surface temperature.\
\>", "Text"],

Cell[BoxData[
    \(B[\[Lambda]_, T_, h_, c_, 
        k_] := \(2\ h\ c\^2\)\/\(\[Lambda]\^5\ \[ExponentialE]\^\(\(h\ \
c\)\/\(\[Lambda]\ k\ T\) - 1\)\)\)], "Input",
  CellLabel->"In[1]:="],

Cell[BoxData[
    \(\(With[{h = 6.623*10\^\(-34\), c = 2.99*10\^8, k = 1.38*10\^\(-23\)}, 
        Plot[{B[\[Lambda], 4000, h, c, k], B[\[Lambda], 5000, h, c, k], 
            B[\[Lambda], 6000, h, c, k], B[\[Lambda], 7000, h, c, k], 
            B[\[Lambda], 8000, h, c, k]}, {\[Lambda], 100\ 10\^\(-9\), 
            1500*10\^\(-9\)}, PlotRange \[Rule] {Automatic, {0, 3\ 10\^14}}, 
          FrameLabel \[Rule] {"\<Wavelength (meters)\>", \*"\"\<Intensity (J/\
\!\(m\^2\)/s/sr)\>\"", "\<\>", "\<\>"}, 
          PlotLabel \[Rule] 
            DisplayForm[
              GridBox[{{StyleBox["\<Blackbody Radiation\>", 
                      FontSize \[Rule] 16, 
                      FontColor \[Rule] 
                        RGBColor[ .7,  .7,  .7]]}, {StyleBox["\<Intensity vs \
Wavelength\>", FontColor \[Rule] Black, FontSize \[Rule] 24]}}, 
                ColumnAlignments -> "\<Left\>"]], ImageSize \[Rule] 550, 
          Frame \[Rule] {True, True, False, False}, 
          TextStyle \[Rule] {FontFamily -> "\<Arial\>", 
              FontWeight -> "\<Bold\>", 
              FontColor \[Rule] RGBColor[ .5,  .5,  .5]}]];\)\)], "Input",
  CellLabel->"In[2]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Wien's Displacement Law", "Subsubsection"],

Cell["\<\
As seen in the plot above, the central wavelength for the peak of radiation \
is dependant on the temperature. If we take the first derivative of the Plank \
distribution and set it to zero, we can find the peak wavelength for a given \
temperature as follows. This is known a Wien's displacement law.\
\>", "Text"],

Cell[BoxData[
    \(Solve[
        D[B[\[Lambda], T, h, c, k], \[Lambda]] \[Equal] 
          0, \[Lambda]] /. {h \[Rule] 6.623*10\^\(-34\), 
        c \[Rule] 2.99*10\^8, k \[Rule] 1.38*10\^\(-23\)}\)], "Input",
  CellLabel->"In[3]:="],

Cell["\<\
As we can see, as the temperature increases, the peak wavelength decreases \
and so the associated star gets more blue as temperature increases.  The \
opposite is also true.  As temperature drops, the star gets more red.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Stefan-Boltzman Law", "Subsubsection"],

Cell["If we integrate the Plank law over all wavelengths", "Text"],

Cell[BoxData[
    \(Assuming[{c \[Element] Reals, h \[Element] Reals, k \[Element] Reals, 
        T > 0, k > 0, c > 0, h > 0}, \[IndentingNewLine]Integrate[
        B[\[Lambda], T, h, c, k], {\[Lambda], 0, \[Infinity]}]]\)], "Input",
  CellLabel->"In[4]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Constructing the H-R Diagram", "Subsection"],

Cell["\<\
The data used in this notebook is a subset of the data in three major \
catalogs: the Hipparcos Catalog, the Yale Bright Star Catalog (5th Edition), \
and the Gliese Catalog of Nearby Stars (3rd Edition). \
\>", "Text"],

Cell["http://www.astronexus.com/data/hyg.html", "Text"],

Cell["\<\
First, we import the data file containing different parameters for a large \
number of stars.\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(SetDirectory[
        ToFileName[\(("\<FileName\>" /. 
                NotebookInformation[
                  EvaluationNotebook[]])\)[\([1]\)]]];\)\), "\
\[IndentingNewLine]", 
    \(\(data = Import["\<hygfull.csv\>", "\<CSV\>"];\)\)}], "Input",
  CellLabel->"In[5]:="],

Cell["Here are the parameters contained in the data file.", "MathCaption"],

Cell[BoxData[
    \(header = data[\([1]\)]\)], "Input",
  CellLabel->"In[7]:="],

Cell["\<\
We can remove the header and then extract the absolute magnitude and color \
index information as data pairs as follows.\
\>", "MathCaption"],

Cell[BoxData[{
    \(\(numdata = Transpose[Drop[data, 1]];\)\), "\n", 
    \(\(AbsMagnitude = numdata[\([12]\)];\)\), "\n", 
    \(\(BV = numdata[\([14]\)];\)\), "\n", 
    \(\(BVAbs = 
        Cases[Transpose[{BV, \(-AbsMagnitude\)}], {x_, 
              y_} /; \((\((NumberQ[x])\) && \((NumberQ[
                    y])\))\)];\)\)}], "Input",
  CellLabel->"In[8]:="],

Cell["\<\
We can convert the color index data into temperature data as follows.  \
Temperature units are in Kelvin.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(TAbs = 
        BVAbs /. {x_, y_} \[Rule] {\(-8540\)/\((x +  .865)\), 
              y};\)\)], "Input",
  CellLabel->"In[12]:="],

Cell["\<\
We can convert the ansolute magnitude data into luminosity data as follows.  \
Luminosity units are in solar luminosities.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(TL = 
        TAbs /. {x_, y_} \[Rule] {x, 
              10^\((\(- .4\)\ \((\(-y\) - 4.77)\))\)};\)\)], "Input",
  CellLabel->"In[13]:="],

Cell["\<\
We can determine the total number of data elements available to us as \
follows.\
\>", "MathCaption"],

Cell[BoxData[
    \(Length[BVAbs]\)], "Input",
  CellLabel->"In[14]:="],

Cell[BoxData[
    \(BVAbs[\([1]\)]\)], "Input",
  CellLabel->"In[15]:="],

Cell["\<\
We can plot the H-R diagram using the B-V and absolute magnitude data as \
follows\
\>", "MathCaption"],

Cell[BoxData[
    \(<< Graphics`\)], "Input",
  CellLabel->"In[16]:="],

Cell[BoxData[
    \(\(hr = 
        Show[Graphics3D[{EdgeForm[], \[IndentingNewLine]SurfaceColor[
                RGBColor[0.5`, 0.7`, 1]], 
              TranslateShape[Sphere[0.2`, 50, 50], {0, 0.2`, 0.2`}], 
              SurfaceColor[RGBColor[0.5`, 0.7`, 1]], 
              TranslateShape[Sphere[0.15`, 50, 50], {0.2`, \(-0.1`\), 0.2`}], 
              SurfaceColor[RGBColor[1, 0, 0]], 
              TranslateShape[Sphere[0.5`, 50, 50], {1.75`, 0.9`, 0.2`}], 
              TranslateShape[Sphere[0.2`, 50, 50], {1.75`, 0.2`, 0.2`}], 
              TranslateShape[
                Sphere[0.05`, 50, 50], {1.75`, \(-1.3`\), 0.2`}], 
              SurfaceColor[RGBColor[1, 0.5`, 0]], 
              TranslateShape[Sphere[0.08`, 50, 50], {1.5`, \(-1\), 0.2`}], 
              TranslateShape[Sphere[0.15`, 50, 50], {1.4`, 0, 0.2`}], 
              SurfaceColor[RGBColor[1, 1, 0.5`]], 
              TranslateShape[Sphere[0.12`, 50, 50], {0.8`, \(-0.5`\), 0.2`}], 
              SurfaceColor[RGBColor[0.8`, 1, 0.9`]], 
              TranslateShape[Sphere[0.13`, 50, 50], {0.5`, \(-0.3`\), 0.2`}], 
              SurfaceColor[RGBColor[1, 1, 0]], 
              TranslateShape[Sphere[0.1`, 50, 50], {1.2`, \(-0.7`\), 0.2`}], 
              SurfaceColor[GrayLevel[1]], 
              TranslateShape[Sphere[0.02`, 50, 50], {0.5`, \(-1.3`\), 0.2`}], 
              PointSize[0.005], 
              Take[BVAbs, 
                  10000] /. {x_, y_} -> {Hue[ .6\ \(( .9 - x/2)\)], 
                    Point[{x, y/10, 0}]}}, 
            PlotLabel \[Rule] 
              DisplayForm[
                GridBox[{{StyleForm["\<Hertzsprung-Russell Diagram\>", 
                        FontSize \[Rule] 16, 
                        FontColor \[Rule] 
                          RGBColor[ .7,  .7,  .7]]}, \
{StyleForm[\*"\"\<\!\(M\_v\) vs B-V\>\"", FontColor \[Rule] White, 
                        FontSize \[Rule] 24]}}, 
                  ColumnAlignments -> "\<Left\>"]], 
            TextStyle \[Rule] {FontFamily -> "\<Arial\>"}, 
            ImageSize \[Rule] 800, Background \[Rule] Black, 
            PlotRange \[Rule] {{\(- .2\), 2.3}, {\(-1.5\), 1.4}, {\(- .2\), 
                  1}}, Boxed -> False, LightSources -> {{{1, 1, 1}, White}}, 
            ViewPoint -> {0, 0, 2}, AmbientLight -> Gray]];\)\)], "Input",
  CellLabel->"In[21]:="],

Cell["\<\
We can plot the H-R diagram using the temperature and absolute magnitude data \
as follows\
\>", "MathCaption"],

Cell[BoxData[
    \(Show[
      ListPlot[TAbs, 
          FrameLabel \[Rule] {"\<-Temperature (K)\>", \*"\"\<-Absolute \
Magnitude (\!\(M\_v\))\>\"", "\<\>", "\<\>"}, 
          PlotLabel \[Rule] 
            DisplayForm[
              GridBox[{{StyleBox["\<Hertzsprung-Russell Diagram\>", 
                      FontSize \[Rule] 16, 
                      FontColor \[Rule] 
                        RGBColor[ .7,  .7,  .7]]}, \
{StyleBox[\*"\"\<\!\(M\_v\) vs T\>\"", FontColor \[Rule] White, 
                      FontSize \[Rule] 24]}}, 
                ColumnAlignments -> "\<Left\>"]], ImageSize \[Rule] 550, 
          Frame \[Rule] {True, True, False, False}, 
          TextStyle \[Rule] {FontFamily -> "\<Arial\>", 
              FontWeight -> "\<Bold\>", 
              FontColor \[Rule] RGBColor[ .5,  .5,  .5]}, 
          Background \[Rule] Black, 
          PlotRange \[Rule] {{\(-14000\), \(-2500\)}, {\(-20\), 10}}, 
          DisplayFunction \[Rule] Identity] /. 
        Point[{x_, y_}] \[Rule] {Hue[ .8\ \((1 - x/12000)\)], Point[{x, y}]}, 
      DisplayFunction \[Rule] $DisplayFunction]\)], "Input",
  CellLabel->"In[22]:="],

Cell["\<\
We can plot the H-R diagram using the temperature and luminosity data as \
follows\
\>", "MathCaption"],

Cell[BoxData[
    \(gr = 
      Show[LogListPlot[TL, Frame \[Rule] True, 
            FrameLabel \[Rule] {"\<-Temperature (K)\>", \*"\"\<Luminosity (\!\
\(\(L\_*\)\)/\!\(L\_sun\))\>\"", "\<\>", "\<\>"}, 
            PlotLabel \[Rule] 
              DisplayForm[
                GridBox[{{StyleBox["\<Hertzsprung-Russell Diagram\>", 
                        FontSize \[Rule] 16, 
                        FontColor \[Rule] 
                          RGBColor[ .7,  .7,  .7]]}, {StyleBox["\<L vs T\>", 
                        FontColor \[Rule] White, FontSize \[Rule] 24]}}, 
                  ColumnAlignments -> "\<Left\>"]], ImageSize \[Rule] 550, 
            Frame \[Rule] {True, True, False, False}, 
            TextStyle \[Rule] {FontFamily -> "\<Arial\>", 
                FontWeight -> "\<Bold\>", 
                FontColor \[Rule] RGBColor[ .5,  .5,  .5]}, 
            Background \[Rule] Black, 
            PlotRange \[Rule] {{\(-14000\), \(-2500\)}, { .00001, 100000}}, 
            DisplayFunction \[Rule] Identity] /. 
          Point[{x_, y_}] \[Rule] {Hue[ .8\ \((1 - x/12000)\)], 
              Point[{x, y}]}, 
        DisplayFunction \[Rule] $DisplayFunction]\)], "Input",
  CellLabel->"In[23]:="],

Cell["\<\
We can animate the data by slowly adding more and more data points and \
showing how an apparent structure starts to emerge.  Styles and color are \
also added for additional effect.\
\>", "MathCaption"],

Cell[BoxData[
    \(\(anim = 
        Table[Show[
            LogListPlot[Take[TL, n], 
                FrameLabel \[Rule] {"\<-Temperature (K)\>", \*"\"\<Luminosity \
(\!\(\(L\_*\)\)/\!\(L\_sun\))\>\"", "\<\>", "\<\>"}, 
                PlotLabel \[Rule] 
                  DisplayForm[
                    GridBox[{{StyleBox["\<Hertzsprung-Russell Diagram\>", 
                            FontSize \[Rule] 16, 
                            FontColor \[Rule] 
                              RGBColor[ .7,  .7,  .7]]}, {StyleBox["\<L vs \
T\>", FontColor \[Rule] White, FontSize \[Rule] 24]}}, 
                      ColumnAlignments -> "\<Left\>"]], 
                ImageSize \[Rule] 550, 
                Frame \[Rule] {True, True, False, False}, 
                TextStyle \[Rule] {FontFamily -> "\<Arial\>", 
                    FontWeight -> "\<Bold\>", 
                    FontColor \[Rule] RGBColor[ .5,  .5,  .5]}, 
                Background \[Rule] Black, 
                PlotRange \[Rule] {{\(-14000\), \(-2500\)}, { .00001, 
                      1000000}}, DisplayFunction \[Rule] Identity] /. 
              Point[{x_, y_}] \[Rule] {Hue[ .8\ \((1 - x/12000)\)], 
                  Point[{x, y}]}, 
            DisplayFunction \[Rule] $DisplayFunction], {n, 1, 2000, 
            16}];\)\)], "Input",
  CellLabel->"In[24]:="]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"5.1 for Microsoft Windows",
ScreenRectangle->{{0, 1280}, {0, 935}},
ScreenStyleEnvironment->"Brackets",
WindowSize->{1022, 799},
WindowMargins->{{84, Automatic}, {Automatic, 26}},
StyleDefinitions -> "HelpBrowser.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1776, 53, 46, 0, 92, "Chapter"],
Cell[1825, 55, 370, 6, 42, "Text"],

Cell[CellGroupData[{
Cell[2220, 65, 32, 0, 39, "Subsection"],
Cell[2255, 67, 447, 7, 59, "Text"],

Cell[CellGroupData[{
Cell[2727, 78, 56, 0, 35, "Subsubsection"],
Cell[2786, 80, 209, 4, 25, "Text"],
Cell[2998, 86, 189, 4, 54, "Input"],
Cell[3190, 92, 1172, 20, 133, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[4399, 117, 48, 0, 35, "Subsubsection"],
Cell[4450, 119, 325, 5, 42, "Text"],
Cell[4778, 126, 236, 5, 30, "Input"],
Cell[5017, 133, 245, 4, 42, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[5299, 142, 44, 0, 35, "Subsubsection"],
Cell[5346, 144, 66, 0, 25, "Text"],
Cell[5415, 146, 258, 4, 49, "Input"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[5722, 156, 50, 0, 39, "Subsection"],
Cell[5775, 158, 229, 4, 42, "Text"],
Cell[6007, 164, 55, 0, 25, "Text"],
Cell[6065, 166, 124, 3, 41, "MathCaption"],
Cell[6192, 171, 293, 7, 49, "Input"],
Cell[6488, 180, 74, 0, 41, "MathCaption"],
Cell[6565, 182, 79, 2, 29, "Input"],
Cell[6647, 186, 151, 3, 41, "MathCaption"],
Cell[6801, 191, 368, 8, 89, "Input"],
Cell[7172, 201, 136, 3, 41, "MathCaption"],
Cell[7311, 206, 150, 4, 29, "Input"],
Cell[7464, 212, 153, 3, 41, "MathCaption"],
Cell[7620, 217, 160, 4, 29, "Input"],
Cell[7783, 223, 111, 3, 41, "MathCaption"],
Cell[7897, 228, 71, 2, 29, "Input"],
Cell[7971, 232, 72, 2, 29, "Input"],
Cell[8046, 236, 113, 3, 41, "MathCaption"],
Cell[8162, 241, 70, 2, 29, "Input"],
Cell[8235, 245, 2339, 41, 309, "Input"],
Cell[10577, 288, 121, 3, 41, "MathCaption"],
Cell[10701, 293, 1145, 23, 129, "Input"],
Cell[11849, 318, 113, 3, 41, "MathCaption"],
Cell[11965, 323, 1217, 23, 129, "Input"],
Cell[13185, 348, 213, 4, 41, "MathCaption"],
Cell[13401, 354, 1339, 26, 129, "Input"]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

